<?php

namespace Drupal\viz_builder_ui\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Asset\AssetResolver;
use Drupal\Core\Asset\AttachedAssets;
use Drupal\Core\File\FileUrlGeneratorInterface;
use Drupal\Core\Render\Renderer;
use Drupal\Component\Serialization\Json;
use Drupal\Core\Extension\ModuleHandler;
use Drupal\Core\Render\HtmlResponse;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\BinaryFileResponse;
use Symfony\Component\HttpFoundation\Request;

use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

class BuilderUIController extends ControllerBase {

  /**
   * @var \Drupal\Core\Asset\AssetResolver
   */
  protected $assetResolver;

  /**
   * @var \Drupal\Core\Render\Renderer
   */
  protected $renderer;

  /**
   * @var \Drupal\Core\File\FileUrlGenerator
   */
  protected $fileUrlGenerator;

  public function __construct(
    AssetResolver $asset_resolver,
    FileUrlGeneratorInterface $file_url_generator,
    Renderer $renderer
  ) {
    $this->assetResolver = $asset_resolver;
    $this->fileUrlGenerator = $file_url_generator;
    $this->renderer = $renderer;
  }

  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('asset.resolver'),
      $container->get('file_url_generator'),
      $container->get('renderer')
    );
  }

  public function serve(Request $request, $file) {
    $uiDir = DRUPAL_ROOT . '/' . \Drupal::moduleHandler()->getModule('viz_builder_ui')->getPath() . '/ui/';
    $target = $request->query->get('file');
    $filepath = $uiDir . $target;

    if (!$target && $file === 'index.html') {
      $contents = file_get_contents($uiDir . 'index.html');
      print $contents;
      exit;
    }

    if (is_file($filepath)) {
      /** @var \Drupal\Core\File\MimeType\MimeTypeGuesser $guesser */
      $guesser = \Drupal::service("file.mime_type.guesser");
      $type = $guesser->guessMimeType($filepath);

      $headers = [
        'Content-Type' => $type,
        'Content-Length' => filesize($filepath),
      ];

      $resp = new BinaryFileResponse($filepath, 200, $headers, true, null, true, true);
      return $resp;
    }

    throw new NotFoundHttpException();
  }
}
