<?php
namespace Drupal\viz_builder\Controller;

use Drupal\Component\Serialization\Json;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Database\Database;
use Drupal\Core\Site\Settings;
use Symfony\Component\HttpFoundation\JsonResponse;

class SDKController extends ControllerBase {

  /**
   * @var \Drupal\viz_builder\SDK
   */
  protected $SDK;

  public function __construct() {
    $this->SDK = \Drupal::service('viz_builder.sdk');
  }

  public function index() {
    $reflection = new \ReflectionClass($this->SDK);
    $methods = $reflection->getMethods();
    $list = [];

    foreach ($methods as $method) {
      $params = [];
      foreach ($method->getParameters() as $param) {
        $params[] = [
          'name' => $param->getName(),
        ];
      }
      $list[] = [
        'name' => $method->getName(),
        'params' => $params,
        'public' => $method->isPublic(),
      ];
    }

    return new JsonResponse($list);
  }

  public function execute() {
    $commands = Json::decode(\Drupal::request()->getContent());
    if (isset($commands['method'])) {
      $commands = [$commands];
    }

    $result = [];
    foreach ($commands as $command) {
      $result[] = $this->invokeSDK($command);
    }

    if (count($commands) == 1) {
      $result = reset($result);
    }

    return new JsonResponse($result);
  }

  protected function invokeSDK($command) {
    $name = $command['method'];
    $parameters = $command['params'] ?? [];
    try {
      $reflection = new \ReflectionClass($this->SDK);
      $reflection->getMethod($name);
      $result = call_user_func_array([$this->SDK, "$name"], $parameters);

      $return = [
        'code' => 200,
        'method' => $name,
        'params' => $parameters,
        'data' => $result,
      ];
    }
    catch (\Exception $e) {
      $return = [
        'code' => 400,
        'data' => null,
        'method' => $name,
        'params' => $parameters,
        'message' => $e->getMessage(),
      ];
    }

    if (isset($command['id'])) {
      $return['id'] = $command['id'];
    }

    return $return;
  }
}
