<?php

namespace Drupal\viz_builder\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Link;
use Drupal\Core\Url;
use Drupal\field\Entity\FieldConfig;

class SettingsController extends ControllerBase {

  protected $field_map = [
    'twig_body' => [
      'lable' => 'Twig body',
      'type' => 'text_long',
    ],
    'builder_data' => [
      'lable' => 'Builder data',
      'type' => 'json_native',
    ],
  ];

  public function index () {
    $build = [];
    $entity_definitions = \Drupal::entityTypeManager()->getDefinitions();
    $entity_types = [];

    foreach ($entity_definitions as $entity_definition) {
      $entity_type_id = $entity_definition->getBundleOf();
      if ($entity_type_id && !$entity_definition->isInternal()) {
        if (in_array($entity_type_id, ['webform_submission', 'shortcut', 'group'])) continue;
        $table = [
          '#type' => 'table',
          '#header' => [t('Bundle'), t('Status'), t('Operation')],
          '#rows' => []
        ];

        $storage = $this->entityTypeManager()->getStorage($entity_definition->id());
        $bundles = \Drupal::service('entity_type.bundle.info')->getBundleInfo($entity_type_id);

        foreach (array_keys($bundles) as $bundle_id) {
          /** @var \Drupal\Core\Config\Entity\ConfigEntityBundleBase $bundle */
          $bundle = $storage->load($bundle_id);
          if (is_null($bundle)) {
            continue;
            //error data, bundle is undefined
            dump($bundle_id);
            exit;
          }
          $enabled = $bundle->getThirdPartySetting('viz_builder', 'builder_enabled', FALSE);
          $operations = [
            '#type' => 'operations',
            '#dropbutton_type' => 'extrasmall',
            '#links' => [
              'toggle' => [
                'title' => !$enabled ? t('Enabled') : t('Disabled'),
                'url' => Url::fromRoute('viz_builder.entity_bundle_confirm', [
                  'entity_type_id' => $entity_type_id,
                  'bundle_id' => $bundle_id
                ])
              ]
            ]
          ];
          
          $row = [
            $bundle->label(),
            $enabled ? t('Enabled') : t('Disabled'),
            \Drupal::service('renderer')->render($operations)
          ];
          $table['#rows'][] = $row;
        }
        $build[] = [
          '#type' => 'details',
          '#title' => $entity_definition->getLabel(),
          'table' => $table,
        ];
      }
    }
    return $build;
  }

}
